@@ -7,7 +7,7 @@ RDF::Query::Node::Resource - RDF Node class for resources
 
 =head1 VERSION
 
-This document describes RDF::Query::Node::Resource version 2.915.
+This document describes RDF::Query::Node::Resource version 2.916.
 
 =cut
 
@@ -21,6 +21,7 @@ use base qw(RDF::Query::Node RDF::Trine::Node::Resource);
 use URI;
 use Encode;
 use Data::Dumper;
+use RDF::Query::Parser::SPARQL;
 use Scalar::Util qw(blessed reftype);
 use Carp qw(carp croak confess);
 
@@ -28,7 +29,7 @@ use Carp qw(carp croak confess);
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '2.915';
+	$VERSION	= '2.916';
 }
 
 ######################################################################
@@ -86,7 +87,7 @@ sub as_sparql {
 			my $v	= $ns{ $k };
 			if (index($uri, $v) == 0) {
 				my $local	= substr($uri, length($v));
-				if ($local =~ /^[A-Za-z_]+$/) {
+				if ($local =~ $RDF::Query::Parser::SPARQL::r_PN_LOCAL) {
 					my $qname	= join(':', $k, $local);
 					return $qname;
 				}
